@@ -62,8 +62,8 @@ class ClientManager(object):
         client.config.data['auth.ssl'] = True
         return client
 
-    def try_connect(self):
-        self.credentials = []
+    def try_connect(self, credentials=[]):
+        self.credentials = credentials
         credentials_location = conffile.get(APP_NAME,'cred.json')            
         if os.path.exists(credentials_location):
             with open(credentials_location) as cf:
@@ -186,6 +186,11 @@ class ClientManager(object):
         del self.clients[uuid]
         client.stop()
 
+    def remove_all_clients(self):
+        for key, client in list(self.clients.items()):
+            del self.clients[key]
+            client.stop()
+
     def stop(self):
         self.is_stopping = True
         for client in self.clients.values():
